summaryrefslogtreecommitdiffstats
path: root/src/com/android/camera/CameraActivity.java
diff options
context:
space:
mode:
Diffstat (limited to 'src/com/android/camera/CameraActivity.java')
-rw-r--r--src/com/android/camera/CameraActivity.java21
1 files changed, 14 insertions, 7 deletions
diff --git a/src/com/android/camera/CameraActivity.java b/src/com/android/camera/CameraActivity.java
index 08b3ba9c7..7f5b8aa28 100644
--- a/src/com/android/camera/CameraActivity.java
+++ b/src/com/android/camera/CameraActivity.java
@@ -1887,13 +1887,20 @@ public class CameraActivity extends QuickActivity
public void onResumeTasks() {
mPaused = false;
- // Show the dialog if necessary. The rest resume logic will be invoked
- // at the onFirstRunStateReady() callback.
- try {
- mFirstRunDialog.showIfNecessary();
- } catch (AssertionError e) {
- Log.e(TAG, "Creating camera controller failed.", e);
- mFatalErrorHandler.onGenericCameraAccessFailure();
+ if (!mSecureCamera) {
+ // Show the dialog if necessary. The rest resume logic will be invoked
+ // at the onFirstRunStateReady() callback.
+ try {
+ mFirstRunDialog.showIfNecessary();
+ } catch (AssertionError e) {
+ Log.e(TAG, "Creating camera controller failed.", e);
+ mFatalErrorHandler.onGenericCameraAccessFailure();
+ }
+ } else {
+ // In secure mode from lockscreen, we go straight to camera and will
+ // show first run dialog next time user enters launcher.
+ Log.v(TAG, "in secure mode, skipping first run dialog check");
+ resume();
}
}